@@ -1,6 +1,6 @@
 """
 toolchest_client.tools.tool
-~~~~~~~~~~~~~~~~~~~~~~
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 This is the base class from which all tools descend.
 Tool must be extended by an implementation (see kraken2.py) to be functional.
@@ -13,11 +13,12 @@ import sys
 from threading import Thread
 import time
 
+from toolchest_client.api.auth import _validate_key
 from toolchest_client.api.exceptions import ToolchestException
 from toolchest_client.api.status import ThreadStatus
 from toolchest_client.api.query import Query
 from toolchest_client.files import files_in_path, split_file_by_lines, sanity_check, check_file_size
-from toolchest_client.tools.arg_whitelist import ARGUMENT_WHITELIST
+from toolchest_client.tools.arg_whitelist import ARGUMENT_WHITELIST, VARIABLE_ARGS
 
 FOUR_POINT_FIVE_GIGABYTES = 4.5 * 1024 * 1024 * 1024
 
@@ -98,12 +99,22 @@ class Tool:
 
         processed_args = []
         following_args = 0
+        # process arguments individually
         for arg in self.tool_args.split():
             if following_args == 0:
+                # if no tag found, skip args until a tag is found
                 if arg in tool_dict:
                     processed_args.append(arg)
                     following_args = tool_dict[arg]
+            elif following_args == VARIABLE_ARGS:
+                # if previous tag has additional args (unknown/variable amount),
+                # append args until another tag is found
+                # TODO: filter out non-escaped bash command-line characters
+                processed_args.append(arg)
+                if arg in tool_dict:
+                    following_args = tool_dict[arg]
             else:
+                # append remaining args if previous tag has additional args
                 # TODO: filter out non-escaped bash command-line characters
                 processed_args.append(arg)
                 following_args -= 1
@@ -236,6 +247,10 @@ class Tool:
     def run(self):
         """Constructs and runs a Toolchest query."""
         print("Beginning Toolchest analysis run.")
+
+        # Validate Toolchest auth key.
+        _validate_key()
+
         # todo: better propagate and handle errors for parallel runs
         self._validate_args()
 
